package com.lantone.security.web;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.lantone.common.api.CommonResult;
import com.lantone.common.dto.DataAuthDTO;
import com.lantone.common.dto.DoctorDTO;
import com.lantone.common.vo.DataAuthVO;
import com.lantone.common.vo.DoctorVO;
import com.lantone.common.vo.ServiceDataAuthVO;
import com.lantone.security.facade.DataAuthHandleFacade;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @ClassName: DataAuthController
 * @Description: 数据权限API
 * @Author songxl
 * @Date 2021/7/21
 * @Version 1.0
 */
@RestController
@Api( value = "数据权限API",tags = "DataAuthController")
@RequestMapping("/data/auth")
public class DataAuthController {
    @Autowired
    private DataAuthHandleFacade dataAuthHandleFacade;

    @ApiOperation(value = "新增数据权限[by:songxl]",
            notes = "dataAuthVO:数据权限对象，必填<br>" +
                    "roles:角色列表，必填<br>" +
                    "type:操作码 1：新增；2：修改 ；3：删除；5:启用禁用")
    @PostMapping("/addAuth")
    @Transactional
    public CommonResult<Boolean> addAuth(@RequestBody ServiceDataAuthVO serviceDataAuthVO) {
        return CommonResult.success(dataAuthHandleFacade.CRUDOperation(serviceDataAuthVO));
    }

    @ApiOperation(value = "修改数据权限[by:songxl]",
            notes = "dataAuthVO:数据权限对象，必填<br>" +
                    "roles:角色列表，必填<br>" +
                    "type:操作码 1：新增；2：修改；3：删除；5:启用禁用")
    @PostMapping("/updateAuth")
    @Transactional
    public CommonResult<Boolean> updateAuth(@RequestBody ServiceDataAuthVO serviceDataAuthVO) {
        return CommonResult.success(dataAuthHandleFacade.CRUDOperation(serviceDataAuthVO));
    }
    @ApiOperation(value = "启用禁用数据权限[by:songxl]",
            notes = "dataAuthVO:数据权限对象，必填<br>" +
                    "roles:角色列表，必填<br>" +
                    "type:操作码 1：新增；2：修改；3：删除；5:启用禁用")
    @PostMapping("/disableAuth")
    @Transactional
    public CommonResult<Boolean> disableAuth(@RequestBody ServiceDataAuthVO serviceDataAuthVO) {
        return CommonResult.success(dataAuthHandleFacade.CRUDOperation(serviceDataAuthVO));
    }

    @ApiOperation(value = "删除数据权限[by:songxl]",
            notes = "dataAuthVO:数据权限对象，必填<br>" +
                    "roles:角色列表，必填<br>" +
                    "type:操作码 1：新增；2：修改；3：删除；5:启用禁用")
    @PostMapping("/deleteAuth")
    @Transactional
    public CommonResult<Boolean> deleteAuth(@RequestBody ServiceDataAuthVO serviceDataAuthVO) {
        return CommonResult.success(dataAuthHandleFacade.CRUDOperation(serviceDataAuthVO));
    }

    @ApiOperation(value = "通过数据权限id和角色id获取数据权限详情[by:songxl]",
            notes = "dataAuthVO:数据权限对象，必填<br>" +
                    "roles:角色列表，必填<br>" +
                    "type:操作码 1：新增；2：修改；3：删除；5:启用禁用")
    @PostMapping("/getDataAuthById")
    public CommonResult<DataAuthDTO> getDataAuthById(@RequestBody ServiceDataAuthVO serviceDataAuthVO) {
        return CommonResult.success(dataAuthHandleFacade.getDataAuthById(serviceDataAuthVO));
    }


    @ApiOperation(value = "获取医生列表[by:songxl]",
            notes = "id:医院编号，必填<br>" +
                    "depts:该医院的科室列表" )
    @PostMapping("/getDoctorPage")
    public CommonResult<IPage<DoctorDTO>> getDoctorPage(@RequestBody DoctorVO doctorVO) {
        return CommonResult.success(dataAuthHandleFacade.getDoctorPage(doctorVO));
    }

    @ApiOperation(value = "获取数据权限列表[by:songxl]",
            notes = "id:医院编号，必填<br>" +
                    "depts:该医院的科室列表" )
    @PostMapping("/getDataAuthPage")
    public CommonResult<IPage<DataAuthDTO>> getDataAuthPage(@RequestBody DataAuthVO dataAuthVO) {
        return CommonResult.success(dataAuthHandleFacade.getDataAuthPage(dataAuthVO));
    }
}
